---
# https://vitepress.dev/reference/default-theme-home-page
layout: home

hero:
  name: "gh2"
  text: "The Python library for creative ASCII art and poetic form"
  tagline: Create computational letterforms in the style of P5, or the best way to learn Python for having fun
  actions:
    - theme: brand
      text: Get Started
      link: /get-started
    - theme: alt
      text: What is gh2?
      link: /what-is-gh2

features:
  - title: Feature A
    details: Lorem ipsum dolor sit amet, consectetur adipiscing elit
  - title: Feature B
    details: Lorem ipsum dolor sit amet, consectetur adipiscing elit
  - title: Feature C
    details: Lorem ipsum dolor sit amet, consectetur adipiscing elit
---
